==> foundation-2.6.1.tgz: package/PageExportCsv/PageExportCsv.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const PageExportCsv = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.284 65.553L75.825 52.411a1.255 1.255 0 00-1.312-.093c-.424.218-.684.694-.685 1.173l.009 6.221H57.231c-.706 0-1.391.497-1.391 1.204v11.442c0 .707.685 1.194 1.391 1.194h16.774v6.27c0 .478.184.917.609 1.136s.853.182 1.242-.097l18.432-13.228c.335-.239.477-.626.477-1.038v-.002c0-.414-.144-.8-.481-1.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M64.06 78.553h-6.49a1.73 1.73 0 00-1.73 1.73h-.007v3.01H15.191V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707h21.188v36.356h.011a1.728 1.728 0 001.726 1.691h6.49c.943 0 1.705-.754 1.726-1.691h.004V12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L5.235 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.089a1.73 1.73 0 001.73-1.73v-2.448h.005v-8.79a1.729 1.729 0 00-1.729-1.728z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M26.18 64.173c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.553-1.273-1.771-2.685-4.193-2.685-2.893 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.193-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.899-2.31 2.242-2.31zm9.476 4.734a4.304 4.304 0 01-2.976-1.19l-1.453 2.076c.982.886 2.325 1.467 4.291 1.467 2.477 0 3.986-1.176 3.986-3.211 0-3.432-5.135-2.685-5.135-3.557 0-.235.152-.415.706-.415.872 0 1.91.304 2.712.913l1.495-1.979c-1.052-.858-2.408-1.287-3.917-1.287-2.533 0-3.833 1.495-3.833 3.059 0 3.64 5.148 2.74 5.148 3.626 0 .359-.498.498-1.024.498zm7.615-7.045h-3.169l3.404 9.231h3.516l3.404-9.231h-3.169l-1.993 6.214z"
  }));
});
PageExportCsv.displayName = 'PageExportCsv';
export const PageExportCsvDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/PageExportCsv/PageExportCsv.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PageExportCsv = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.284 65.553L75.825 52.411a1.255 1.255 0 00-1.312-.093c-.424.218-.684.694-.685 1.173l.009 6.221H57.231c-.706 0-1.391.497-1.391 1.204v11.442c0 .707.685 1.194 1.391 1.194h16.774v6.27c0 .478.184.917.609 1.136s.853.182 1.242-.097l18.432-13.228c.335-.239.477-.626.477-1.038v-.002c0-.414-.144-.8-.481-1.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M64.06 78.553h-6.49a1.73 1.73 0 00-1.73 1.73h-.007v3.01H15.191V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707h21.188v36.356h.011a1.728 1.728 0 001.726 1.691h6.49c.943 0 1.705-.754 1.726-1.691h.004V12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L5.235 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.089a1.73 1.73 0 001.73-1.73v-2.448h.005v-8.79a1.729 1.729 0 00-1.729-1.728z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M26.18 64.173c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.553-1.273-1.771-2.685-4.193-2.685-2.893 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.193-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.899-2.31 2.242-2.31zm9.476 4.734a4.304 4.304 0 01-2.976-1.19l-1.453 2.076c.982.886 2.325 1.467 4.291 1.467 2.477 0 3.986-1.176 3.986-3.211 0-3.432-5.135-2.685-5.135-3.557 0-.235.152-.415.706-.415.872 0 1.91.304 2.712.913l1.495-1.979c-1.052-.858-2.408-1.287-3.917-1.287-2.533 0-3.833 1.495-3.833 3.059 0 3.64 5.148 2.74 5.148 3.626 0 .359-.498.498-1.024.498zm7.615-7.045h-3.169l3.404 9.231h3.516l3.404-9.231h-3.169l-1.993 6.214z"
  }));
});
PageExportCsv.displayName = 'PageExportCsv';
export var PageExportCsvDimensions = {
  height: 100,
  width: 100
};
